.. _fluent_pages.sitemaps:

fluent_pages.sitemaps
=====================

.. automodule:: fluent_pages.sitemaps

The ``PageSitemap`` class
-------------------------

.. autoclass:: fluent_pages.sitemaps.PageSitemap
   :members:

